# Context Engine API

The central nervous system of the Clew.

**Tech Stack:**
*   Python 3.11+
*   FastAPI
*   Pydantic

**Responsibilities:**
*   Hybrid Search (`/v1/search`)
*   Graph Traversal (`/v1/graph`)
*   Data Ingestion Webhooks (`/v1/ingest`)
